(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{30:function(e,t,a){e.exports=a(40)},40:function(e,t,a){"use strict";a.r(t);var r,n,i=a(6),c=a.n(i),o=a(28),s=a.n(o),l=a(26),p=a(0),d=a(1),m=a(2),u=a(3),g=a(21),h=a(22),b=a(16),f=a(29),x=a.n(f),v=function(e){Object(m.a)(a,e);var t=Object(u.a)(a);function a(){var e;Object(d.a)(this,a);for(var i=arguments.length,o=new Array(i),s=0;s<i;s++)o[s]=arguments[s];return(e=t.call.apply(t,[this].concat(o))).render=function(){var t,a=e.props.args,i=a.isUser,o=a.avatarStyle,s=a.seed,p=a.initial_text,d=a.complete_text,m=a.useTypewriter;t=o.startsWith("https")||o.startsWith("data:image")?o:"https://avatars.dicebear.com/api/".concat(o,"/").concat(s,".svg");var u=e.props.theme;if(!u)return c.a.createElement("div",null,"Theme is undefined, please check streamlit version.");var f=h.a.img({border:"1px solid transparent",height:"3rem",width:"3rem",margin:0}),v=h.a.div({display:"inline-block",background:u.secondaryBackgroundColor,border:"1px solid transparent",borderRadius:"10px",padding:"10px 14px",margin:"5px 20px",maxWidth:"70%",whiteSpace:"pre-wrap"}),y=h.a.div({display:"flex",fontFamily:"".concat(u.font,", 'Segoe UI', 'Roboto', sans-serif"),height:"auto",margin:0,width:"100%"},(function(e){return e.isUser?Object(b.a)(r||(r=Object(l.a)(["\n          flex-direction: row-reverse;\n          & > div {\n            text-align: right;\n          }\n          padding-right: 5px;\n        "]))):Object(b.a)(n||(n=Object(l.a)([""])))}));return!i&&m?c.a.createElement(y,{isUser:i},c.a.createElement(f,{src:t,alt:"profile",draggable:"false"}),c.a.createElement(v,null,c.a.createElement(x.a,{options:{delay:10,cursor:"\u258e",onCreateTextNode:function(e){return g.a.setFrameHeight(),document.createTextNode(e)}},onInit:function(e){e.pasteString(p,null).typeString(d.split(p).join("")).callFunction((function(t){e.stop()})).start()}}))):c.a.createElement(y,{isUser:i},c.a.createElement(f,{src:t,alt:"profile",draggable:"false"}),c.a.createElement(v,null,d))},e}return Object(p.a)(a)}(g.b),y=Object(g.c)(v);s.a.render(c.a.createElement(c.a.StrictMode,null,c.a.createElement(y,null)),document.getElementById("root"))}},[[30,1,2]]]);
//# sourceMappingURL=main.fcf469a7.chunk.js.map